@@ -48,6 +48,10 @@ public:
     void redo() override;
     /// revert the actions done in redo
     void undo() override;
+
+    int id() const override;
+    bool mergeWith(const KUndo2Command *command) override;
+
 private:
     KoParameterShape *m_shape;
     int m_handleId;
