@@ -348,7 +348,6 @@ private:
 struct Q_DECL_HIDDEN KisScanlineFill::Private
 {
     KisPaintDeviceSP device;
-    KisRandomAccessorSP it;
     QPoint startPoint;
     QRect boundingRect;
     int threshold;
@@ -374,7 +373,6 @@ KisScanlineFill::KisScanlineFill(KisPaintDeviceSP device, const QPoint &startPoi
     : m_d(new Private)
 {
     m_d->device = device;
-    m_d->it = device->createRandomAccessorNG(startPoint.x(), startPoint.y());
     m_d->startPoint = startPoint;
     m_d->boundingRect = boundingRect;
 
