@@ -19,12 +19,10 @@
 #include <QTest>
 
 #include <KritaVersionWrapper.h>
-#include <QTest>
 #include <QColor>
 #include <QDataStream>
 #include <QDir>
 
-#include <KritaVersionWrapper.h>
 #include <Node.h>
 #include <Krita.h>
 #include <Document.h>
@@ -39,6 +37,8 @@
 #include <kis_paint_layer.h>
 #include <KisPart.h>
 
+#include <sdk/tests/kistest.h>
+
 void TestDocument::testSetColorSpace()
 {
     KisDocument *kisdoc = KisPart::instance()->createDocument();
@@ -53,7 +53,9 @@ void TestDocument::testSetColorSpace()
 
     QVERIFY(layer->colorSpace()->colorModelId().id() == "GRAYA");
     QVERIFY(layer->colorSpace()->colorDepthId().id() == "U16");
-    QVERIFY(layer->colorSpace()->profile()->name() == "gray built-in");
+    QVERIFY(layer->colorSpace()->profile()->name() == profiles.first());
+
+    KisPart::instance()->removeDocument(kisdoc);
 }
 
 void TestDocument::testSetColorProfile()
@@ -71,6 +73,7 @@ void TestDocument::testSetColorProfile()
         d.setColorProfile(profile);
         QVERIFY(image->colorSpace()->profile()->name() == profile);
     }
+    KisPart::instance()->removeDocument(kisdoc);
 }
 
 void TestDocument::testPixelData()
@@ -99,6 +102,8 @@ void TestDocument::testPixelData()
         ds >> channelvalue;
         QVERIFY(channelvalue == 255);
     } while (!ds.atEnd());
+
+    KisPart::instance()->removeDocument(kisdoc);
 }
 
 void TestDocument::testThumbnail()
@@ -129,36 +134,7 @@ void TestDocument::testThumbnail()
 #endif
         }
     }
-
-}
-
-void TestDocument::testCreateAndSave()
-{
-    KisDocument *kisdoc = KisPart::instance()->createDocument();
-    KisImageSP image = new KisImage(0, 5000, 5000, KoColorSpaceRegistry::instance()->rgb16(), "test");
-    KisNodeSP layer = new KisPaintLayer(image, "test1", 128);
-    KisFillPainter gc(layer->paintDevice());
-    gc.fillRect(100, 100, 4000, 4000, KoColor(Qt::red, layer->colorSpace()));
-    image->addNode(layer);
-    for(int i = 0; i < 10; ++i) {
-        image->addNode(layer->clone());
-    }
-    kisdoc->setCurrentImage(image);
-
-    Document d(kisdoc);
-    d.setBatchmode(true);
-    d.refreshProjection();
-
-    QString filename = QDir::tempPath() + "/TestDocumentTestCreateAndSave.kra";
-
-    d.saveAs(filename);
-    QVERIFY2(QFileInfo(filename).exists(), filename.toUtf8());
-
-    Document *d2 = Krita::instance()->openDocument(filename);
-    Q_ASSERT(d2->colorDepth() == "U16");
-
-    delete kisdoc;
-    delete d2;
+    KisPart::instance()->removeDocument(kisdoc);
 
 }
 
@@ -204,11 +180,11 @@ void TestDocument::testCreateFillLayer()
 
     QVERIFY(d.createFillLayer("test1", "xxx", info, sel) == 0);
 
-    delete kisdoc;
+    KisPart::instance()->removeDocument(kisdoc);
 
 }
 
 
 
-QTEST_MAIN(TestDocument)
+KISTEST_MAIN(TestDocument)
 
