@@ -51,7 +51,6 @@
 #include <QMoveEvent>
 #include <QUrl>
 #include <QMessageBox>
-#include <QTemporaryFile>
 #include <QStatusBar>
 #include <QMenu>
 #include <QMenuBar>
@@ -59,7 +58,7 @@
 #include <QMimeData>
 #include <QStackedWidget>
 #include <QProxyStyle>
-
+#include <QScreen>
 
 #include <kactioncollection.h>
 #include <QAction>
@@ -74,9 +73,6 @@
 #include "kis_selection_manager.h"
 #include "kis_icon_utils.h"
 
-#ifdef HAVE_KIO
-#include <krecentdocument.h>
-#endif
 #include <krecentfilesaction.h>
 #include <KoResourcePaths.h>
 #include <ktoggleaction.h>
@@ -146,8 +142,8 @@
 #include "KisWindowLayoutManager.h"
 #include <KisUndoActionsUpdateManager.h>
 #include "KisWelcomePageWidget.h"
-#include <QScreen>
-
+#include <KritaVersionWrapper.h>
+#include <kritaversion.h>
 #include <mutex>
 
 #ifdef Q_OS_WIN
@@ -382,19 +378,17 @@ KisMainWindow::KisMainWindow(QUuid uuid)
     d->mdiArea->setTabPosition(QTabWidget::North);
     d->mdiArea->setTabsClosable(true);
 
-
     // Tab close button override
     // Windows just has a black X, and Ubuntu has a dark x that is hard to read
     // just switch this icon out for all OSs so it is easier to see
     d->mdiArea->setStyleSheet("QTabBar::close-button { image: url(:/pics/broken-preset.png) }");
 
-
-
     setCentralWidget(d->widgetStack);
     d->widgetStack->setCurrentIndex(0);
 
     connect(d->mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow*)), this, SLOT(subWindowActivated()));
-    connect(d->windowMapper, SIGNAL(mapped(QWidget*)), this, SLOT(setActiveSubWindow(QWidget*)));    connect(d->documentMapper, SIGNAL(mapped(QObject*)), this, SLOT(newView(QObject*)));
+    connect(d->windowMapper, SIGNAL(mapped(QWidget*)), this, SLOT(setActiveSubWindow(QWidget*)));
+    connect(d->documentMapper, SIGNAL(mapped(QObject*)), this, SLOT(newView(QObject*)));
 
     createActions();
 
@@ -406,7 +400,6 @@ KisMainWindow::KisMainWindow(QUuid uuid)
     subWindowActivated();
     updateWindowMenu();
 
-
     if (isHelpMenuEnabled() && !d->helpMenu) {
         // workaround for KHelpMenu (or rather KAboutData::applicationData()) internally
         // not using the Q*Application metadata ATM, which results e.g. in the bugreport wizard
@@ -456,7 +449,6 @@ KisMainWindow::KisMainWindow(QUuid uuid)
     helpAction->disconnect();
     connect(helpAction, SIGNAL(triggered()), this, SLOT(showManual()));
 
-
 #if 0
     //check for colliding shortcuts
     QSet<QKeySequence> existingShortcuts;
@@ -482,6 +474,7 @@ KisMainWindow::KisMainWindow(QUuid uuid)
     QList<QAction *> toolbarList;
     Q_FOREACH (QWidget* it, guiFactory()->containers("ToolBar")) {
         KToolBar * toolBar = ::qobject_cast<KToolBar *>(it);
+        toolBar->setMovable(KisConfig().readEntry<bool>("LockAllDockerPanels", false));
 
         if (toolBar) {
             if (toolBar->objectName() == "BrushesAndStuff") {
@@ -498,6 +491,8 @@ KisMainWindow::KisMainWindow(QUuid uuid)
             warnUI << "Toolbar list contains a " << it->metaObject()->className() << " which is not a toolbar!";
         }
     }
+
+    KToolBar::setToolBarsLocked(KisConfig().readEntry<bool>("LockAllDockerPanels", false));
     plugActionList("toolbarlist", toolbarList);
     d->toolbarList = toolbarList;
 
@@ -724,17 +719,7 @@ void KisMainWindow::addRecentURL(const QUrl &url)
                     break;
                 }
             }
-#ifdef HAVE_KIO
-            if (ok) {
-                KRecentDocument::add(QUrl::fromLocalFile(path));
-            }
-#endif
         }
-#ifdef HAVE_KIO
-        else {
-            KRecentDocument::add(url.adjusted(QUrl::StripTrailingSlash));
-        }
-#endif
         if (ok) {
             d->recentFiles->addUrl(url);
         }
@@ -794,52 +779,33 @@ void KisMainWindow::updateCaption()
             caption += " [" + i18n("Recovered") + "] ";
         }
 
-
-        // new documents aren't saved yet, so we don't need to say it is modified
-        // new files don't have a URL, so we are using that for the check
-        if (!doc->url().isEmpty()) {
-
-            if ( doc->isModified()) {
-                caption += " [" + i18n("Modified") + "] ";
-            }
-        }
-
         // show the file size for the document
-
-
         KisMemoryStatisticsServer::Statistics m_fileSizeStats = KisMemoryStatisticsServer::instance()->fetchMemoryStatistics(d->activeView ? d->activeView->image() : 0);
 
-
         if (m_fileSizeStats.imageSize) {
             caption += QString(" (").append( KFormat().formatByteSize(m_fileSizeStats.imageSize)).append( ")");
         }
 
-
         d->activeView->setWindowTitle(caption);
         d->activeView->setWindowModified(doc->isModified());
 
         updateCaption(caption, doc->isModified());
 
-        if (!doc->url().fileName().isEmpty())
+        if (!doc->url().fileName().isEmpty()) {
             d->saveAction->setToolTip(i18n("Save as %1", doc->url().fileName()));
-        else
+        }
+        else {
             d->saveAction->setToolTip(i18n("Save"));
+        }
     }
 }
 
 void KisMainWindow::updateCaption(const QString & caption, bool mod)
 {
     dbgUI << "KisMainWindow::updateCaption(" << caption << "," << mod << ")";
-#ifdef KRITA_ALPHA
-    setCaption(QString("ALPHA %1: %2").arg(KRITA_ALPHA).arg(caption), mod);
-    return;
-#endif
-#ifdef KRITA_BETA
-    setCaption(QString("BETA %1: %2").arg(KRITA_BETA).arg(caption), mod);
-    return;
-#endif
-#ifdef KRITA_RC
-    setCaption(QString("RELEASE CANDIDATE %1: %2").arg(KRITA_RC).arg(caption), mod);
+    QString versionString = KritaVersionWrapper::versionString(true);
+#if defined(KRITA_ALPHA) || defined (KRITA_BETA) || defined (KRITA_RC)
+    setCaption(QString("%1: %2").arg(versionString).arg(caption), mod);
     return;
 #endif
 
@@ -1962,7 +1928,6 @@ QDockWidget* KisMainWindow::createDockWidget(KoDockFactoryBase* factory)
     QDockWidget* dockWidget = 0;
     bool lockAllDockers = KisConfig().readEntry<bool>("LockAllDockerPanels", false);
 
-
     if (!d->dockWidgetsMap.contains(factory->id())) {
         dockWidget = factory->createDockWidget();
 
@@ -2124,11 +2089,12 @@ void KisMainWindow::subWindowActivated()
     QMdiSubWindow *subWindow = d->mdiArea->currentSubWindow();
     if (subWindow) {
         QMenu *menu = subWindow->systemMenu();
-        if (menu) {
+        if (menu && menu->actions().size() == 8) {
             Q_FOREACH (QAction *action, menu->actions()) {
                 action->setShortcut(QKeySequence());
-                action->deleteLater();
+
             }
+            menu->actions().last()->deleteLater();
         }
     }
 
@@ -2141,11 +2107,12 @@ void KisMainWindow::windowFocused()
     /**
      * Notify selection manager so that it could update selection mask overlay
      */
-    viewManager()->selectionManager()->selectionChanged();
+    if (viewManager() && viewManager()->selectionManager()) {
+        viewManager()->selectionManager()->selectionChanged();
+    }
 
-
-    auto *kisPart = KisPart::instance();
-    auto *layoutManager = KisWindowLayoutManager::instance();
+    KisPart *kisPart = KisPart::instance();
+    KisWindowLayoutManager *layoutManager = KisWindowLayoutManager::instance();
     if (!layoutManager->primaryWorkspaceFollowsFocus()) return;
 
     QUuid primary = layoutManager->primaryWindowId();
