@@ -120,6 +120,18 @@ void KisToolInvocationAction::begin(int shortcut, QEvent *event)
          * key event and the method call
          */
         inputManager()->canvas()->image()->requestStrokeEnd();
+
+        /**
+         * Some tools would like to distinguish automated requestStrokeEnd()
+         * calls from explicit user actions. Just let them do it!
+         *
+         * Please note that this call should happen **after**
+         * requestStrokeEnd(). Some of the tools will switch to another
+         * tool on this request, and this (next) tool does not expect to
+         * get requestStrokeEnd() right after switching in.
+         */
+        inputManager()->toolProxy()->explicitUserStrokeEndRequest();
+
     } else if (shortcut == CancelShortcut) {
         /**
          * The tools now have a KisTool::requestStrokeCancellation() method,
@@ -133,9 +145,12 @@ void KisToolInvocationAction::begin(int shortcut, QEvent *event)
 void KisToolInvocationAction::end(QEvent *event)
 {
     if (d->active) {
-        inputManager()->toolProxy()->
-            forwardEvent(KisToolProxy::END, KisTool::Primary, event, event);
-
+        // It might happen that the action is still running, while the
+        // canvas has been removed, which kills the toolProxy.
+        if (inputManager() && inputManager()->toolProxy()) {
+            inputManager()->toolProxy()->
+                    forwardEvent(KisToolProxy::END, KisTool::Primary, event, event);
+        }
         d->active = false;
     }
 
